var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/compiler.ts
var compiler_exports = {};
__export(compiler_exports, {
  compile: () => compile
});
module.exports = __toCommonJS(compiler_exports);
var import_rehype_pretty_code = __toESM(require("rehype-pretty-code"));
var import_plugin_utils = require("umi/plugin-utils");
var import_mdx = require("../compiled/@mdx-js/mdx");
var import_rehype_slug = __toESM(require("../compiled/rehype-slug"));
var import_remark_gfm = __toESM(require("../compiled/remark-gfm"));
var import_rehype_autolink_headings = __toESM(require("../compiled/rehype-autolink-headings"));
var rehypePrettyCodeOptions = {
  theme: "dark-plus",
  onVisitLine(node) {
    if (node.children.length === 0) {
      node.children = [{ type: "text", value: " " }];
    }
  },
  // 允许高亮代码行
  // 对于高亮的代码行，设置为 highlighted 样式表类
  onVisitHighlightedLine(node) {
    node.properties.className.push("highlighted");
  },
  // 允许高亮代码文字
  // 对于高亮的代码文字，设置为 word 样式表类
  onVisitHighlightedWord(node) {
    node.properties.className = ["word"];
  }
};
async function compile(opts) {
  const compiler = (0, import_mdx.createProcessor)({
    jsx: true,
    remarkPlugins: [import_remark_gfm.default],
    rehypePlugins: [
      import_rehype_slug.default,
      [import_rehype_pretty_code.default, rehypePrettyCodeOptions],
      import_rehype_autolink_headings.default
    ]
  });
  try {
    let result = String(await compiler.process(opts.content));
    result = result.replace(
      "function MDXContent(props = {}) {",
      `
import { useEffect } from 'react';

function MDXContent(props = {}) {

  useEffect(() => {
    if (window.location.hash.length !== 0) {
      // 为了右侧内容区能正常跳转
      const hash = decodeURIComponent(window.location.hash);
      setTimeout(() => {
        document.getElementById(hash.slice(1))?.scrollIntoView();
      }, 100);
    } else {
      window.scrollTo(0, 0);
    }
    document.getElementById('active-nav-item')?.scrollIntoView({
      behavior: 'smooth',
      block: 'center'
    });
  }, []);

`
    );
    return { result };
  } catch (e) {
    import_plugin_utils.logger.error(e.reason);
    import_plugin_utils.logger.error(`Above error occurred in ${opts.fileName} at line ${e.line}`);
    import_plugin_utils.logger.error(
      opts.content.split("\n").filter((_, i) => i == e.line - 1).join("\n")
    );
    import_plugin_utils.logger.error(" ".repeat(e.column - 1) + "^");
    if (process.env.NODE_ENV === "production") {
      throw new Error("compile error", { cause: e });
    }
    return { result: "" };
  }
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  compile
});
